==> annot8-conventions-0.4.0-sources.jar: io/annot8/conventions/PropertyKeys.java <==
/* Annot8 (annot8.io) - Licensed under Apache-2.0. */
package io.annot8.conventions;

public class PropertyKeys {

  public static final String PROPERTY_KEY_ACCESSEDAT = "accessedAt";
  public static final String PROPERTY_KEY_ACCOUNTNUMBER = "accountNumber";
  public static final String PROPERTY_KEY_ACCOUNTTYPE = "accountType";
  public static final String PROPERTY_KEY_BRANCHCODE = "branchCode";
  public static final String PROPERTY_KEY_BANKCODE = "bankCode";
  public static final String PROPERTY_KEY_COORDINATETYPE = "coordinateType";
  public static final String PROPERTY_KEY_COUNTRY = "country";
  public static final String PROPERTY_KEY_DATE = "date";
  public static final String PROPERTY_KEY_END = "end";
  public static final String PROPERTY_KEY_FIRSTNAME = "firstname";
  public static final String PROPERTY_KEY_GENDER = "gender";
  public static final String PROPERTY_KEY_GEOJSON = "geojson";
  public static final String PROPERTY_KEY_IDENTIFIER = "identifier";
  public static final String PROPERTY_KEY_LANGUAGE = "language";
  public static final String PROPERTY_KEY_LATITUDE = "latitude";
  public static final String PROPERTY_KEY_LEMMA = "lemma";
  public static final String PROPERTY_KEY_LONGITUDE = "longitude";
  public static final String PROPERTY_KEY_NAME = "name";
  public static final String PROPERTY_KEY_NATIONALITY = "nationality";
  public static final String PROPERTY_KEY_PROBABILITY = "probability";
  public static final String PROPERTY_KEY_PARTOFSPEECH = "pos";
  public static final String REGISTRATION = "registration";
  public static final String PROPERTY_KEY_REFERENCE = "reference";
  public static final String PROPERTY_KEY_SOURCE = "source";
  public static final String PROPERTY_KEY_START = "start";
  public static final String PROPERTY_KEY_SUBTYPE = "subtype";
  public static final String PROPERTY_KEY_SURNAME = "surname";
  public static final String PROPERTY_KEY_TITLE = "title";
  public static final String PROPERTY_KEY_UNIT = "unit";
  public static final String PROPERTY_KEY_VALUE = "value";
  public static final String PROPERTY_KEY_VERSION = "version";

  private PropertyKeys() {
    // No constructor - only access to public methods
  }
}

==> annot8-conventions-1.1.0-sources.jar: io/annot8/conventions/PropertyKeys.java <==
/* Annot8 (annot8.io) - Licensed under Apache-2.0. */
package io.annot8.conventions;

public class PropertyKeys {

  public static final String PROPERTY_KEY_ACCESSEDAT = "accessedAt";
  public static final String PROPERTY_KEY_ACCOUNTNUMBER = "accountNumber";
  public static final String PROPERTY_KEY_ACCOUNTTYPE = "accountType";
  public static final String PROPERTY_KEY_BRANCHCODE = "branchCode";
  public static final String PROPERTY_KEY_BANKCODE = "bankCode";
  public static final String PROPERTY_KEY_COORDINATETYPE = "coordinateType";
  public static final String PROPERTY_KEY_COUNTRY = "country";
  public static final String PROPERTY_KEY_DATE = "date";
  public static final String PROPERTY_KEY_DESCRIPTION = "description";
  public static final String PROPERTY_KEY_ELEVATION = "elevation";
  public static final String PROPERTY_KEY_END = "end";
  public static final String PROPERTY_KEY_FIRSTNAME = "firstname";
  public static final String PROPERTY_KEY_GENDER = "gender";
  public static final String PROPERTY_KEY_GEOJSON = "geojson";
  public static final String PROPERTY_KEY_IDENTIFIER = "identifier";
  public static final String PROPERTY_KEY_INDEX = "index";
  public static final String PROPERTY_KEY_LANGUAGE = "language";
  public static final String PROPERTY_KEY_LATITUDE = "latitude";
  public static final String PROPERTY_KEY_LEMMA = "lemma";
  public static final String PROPERTY_KEY_LONGITUDE = "longitude";
  public static final String PROPERTY_KEY_MIMETYPE = "mimeType";
  public static final String PROPERTY_KEY_NAME = "name";
  public static final String PROPERTY_KEY_NATIONALITY = "nationality";
  public static final String PROPERTY_KEY_PAGE = "page";
  public static final String PROPERTY_KEY_PARTOFSPEECH = "pos";
  public static final String PROPERTY_KEY_PROBABILITY = "probability";
  public static final String REGISTRATION = "registration";
  public static final String PROPERTY_KEY_REFERENCE = "reference";
  public static final String PROPERTY_KEY_SOURCE = "source";
  public static final String PROPERTY_KEY_START = "start";
  public static final String PROPERTY_KEY_SUBTYPE = "subtype";
  public static final String PROPERTY_KEY_SURNAME = "surname";
  public static final String PROPERTY_KEY_TITLE = "title";
  public static final String PROPERTY_KEY_UNIT = "unit";
  public static final String PROPERTY_KEY_VALUE = "value";
  public static final String PROPERTY_KEY_VERSION = "version";

  private PropertyKeys() {
    // No constructor - only access to public methods
  }
}
